from setuptools import setup

setup(name='distributions_for_dsnd',
      version='0.2',
      description='Gaussian distributions',
      packages=['distributions_for_dsnd'],
      author = 'Mona Anderssen',
      zip_safe=False)
